/*globals define*/

define([
    'testsuite/qunit',
    'testsuite/qunit-fixture!ep/ui/validate-test',
    'jquery',

    'ep/ui/validate',
    'ep/ui/form',
    'jquery/metaparse',
    '$ready!'
], function (QUnit, fixture, $, ep) {

    QUnit.module("ep/ui/validate", {
        setup: fixture.init,
        teardown: fixture.destroy
    });

    QUnit.asyncTest("ep/ui/validate", function () {

        $('.ep-js').metaparse();

        QUnit.equal(
            $('.ep-uiValidate').length,
            11,
            "$('.ep-uiValidate').length"
        );

        QUnit.equal(
            $(':input:invalid').length,
            1,
            "One input is invalid on start up"
        );

        $(':input')
            .trigger('validate');

        QUnit.equal(
            $(':input:invalid').length,
            10,
            "$(':input:invalid').length"
        );

        $(':input[name="text_a"]')
            .val('Text')
            .trigger('validate');

        QUnit.equal(
            $(':input:invalid').length,
            9,
            "$(':input:invalid').length"
        );

        $(':input[name="text_c"]')
            .val(12)
            .trigger('validate');

        QUnit.equal(
            $(':input:invalid').length,
            9,
            "$(':input:invalid').length"
        );

        ep(':input[name="text_c"]')
            .uiValidate({'valid' : true})
            .trigger('changeAttr', {'required' : false})
            .trigger('changeAttr', {'max' : 15});

        QUnit.equal(
            $(':input:invalid').length,
            8,
            "$(':input:invalid').length"
        );

        $(':input[name="text_d"]')
            .val("07.02.2013")
            .trigger('validate');

        QUnit.equal(
            $(':input:invalid').length,
            7,
            "$(':input:invalid').length"
        );

        $(':input[name="check_a"]')
            .prop('checked', true)
            .trigger('validate');

        QUnit.equal(
            $(':input:invalid').length,
            6,
            "$(':input:invalid').length"
        );

        $(':input[name="check_b"]')
            .prop('checked', true)
            .trigger('validate');

        QUnit.equal(
            $(':input:invalid').length,
            5,
            "$(':input:invalid').length"
        );

        $(':input[name="radio_a"]')
            .prop('checked', true)
            .trigger('validate');

        QUnit.equal(
            $(':input:invalid').length,
            3,
            "$(':input:invalid').length"
        );

        $(':input[name="select_b"] option:eq(1)')
            .prop('selected', true)
            .parent()
            .trigger('validate');

        QUnit.equal(
            $(':input:invalid').length,
            2,
            "$(':input:invalid').length"
        );

        $(':input[name="texarea_a"]')
            .val('Text')
            .trigger('validate');

        QUnit.equal(
            $(':input:invalid').length,
            1,
            "$(':input:invalid').length"
        );

        ep('.ep-uiValidate').each(function () {
            ep(this).uiValidate('destroy');
        });

        var hasClassUiValidate = false;

        $('input, select, textarea').each(function () {
            if ($(this).hasClass(/ep-uiValidate[\w\d\-]*/g)) {
                hasClassUiValidate = true;
            }
        });

        QUnit.equal(
            hasClassUiValidate,
            false,
            "the destroy method has successfully deleted the class ep-uiValidate(-message) from every form element"
        );

        QUnit.start();
    });
});